%include 'c:\temp\stattool.sas';

options linesize=100 pagesize=60;

ods html body='c:\temp\stattool user guide.html';
data test;
title1 "STATTOOL";

if _n_=1 Then do;
   file print;
   put @2 "You've just activated the SAS macro STATTOOL" / ;
   put @2 "STATTOOL USER GUIDE" /;
   put @2 "Mandatory Parameters: " /;
   put @2 "WGT=      put the population weight variable " ;
   put @2 "RWGT=     put the root of the variables specifying the replicate weights if any." ;
   put @2 "          Don't specify this parameter for ALL, TIMSS and PIRLS data files " ;
   put @2 "NREP=     put the number of sets of replicate weights " ;
   put @2 "NPV=      put the number of sets of plausible values. (NPV=1 by default) " ;
   put @2 "STUDY=    put the name of the study (ALL, TIMSS, PIRLS, PISA, OTHERS) " ;
   put @2 "          if OTHERS, then a correction factor must be specified with the C parameter" ;
   put @2 "          For example C=1 would be needed for a JK2 approach. " ;
   put @2 "CNTRYNO=  put the country identifier. " ;
   put @2 "INFILE=   put the name of the temporary SAS file containing the data  " ;
   put @2 "          INFILE= setup is reserved for the percent correct procedure only." ;
   put @2 "OUT=      put the name of the HTML file output file that will contain the output results.  " ;
   put @2 "          No quotes or double quotes allowed.  " ;
   put @2 "METHOD=   put the name of the required analysis: " / ;

   put @12 "Standard linear regression of y over x"  /;
   put @12 "METHOD=regr"  /;
   put @20 "Mandatory Parameters : " /;
   put @20 "DVAR=    put the name of the dependent y-variable or only the root" / @29
           "if based on plausible values - No more than one variable " ;
   put @20 "DVARPV=  indicates whether the DVAR variable is based on  " / @29
           "plausible values (DVARPV=1) or not (DVARPV=0) " ;
   put @20 "IVAR=    put the name of all independent x-variable(s) or put only the root(s)" / @29
           "if based on plausible values (x1-x9 not allowed)" ;
   put @20 "IVARPV=  indicates whether the IVAR variable(s) is(are) based on  " / @29
           "plausible values or not. -IVARPV=0 0 1- tells us that the first  " / @29
           "two IVAR variables are not based on plausible values but" / @29
           "the last one is" / ;
   put @20 "Optional Parameters : " /;
   put @20 "BYVAR=   put the name of the subpopulation variable(s) or only the root" / @29
           "if based on plausible values" ;
   put @20 "BYVARPV= indicates whether the BYVAR variable(s) is(are) based on " / @29
           "plausible values or not. -BYVARPV=0 0 1- tells us that the first  " / @29
           "two BYVAR variables are not based on plausible values but" / @29
           "the last one is"  ;
   put @20 "CLVAR=   put the name of the qualitative independent x-variable(s) or only " / @29
           "the root if based on plausible values. CLVAR is a subset of IVAR" / @29
           "The highest levels of each CLVAR variable become the reference cells." ;
   put @20 "INTERACTION= specifies the interaction terms. <VAR1*VAR2>, <VAR1*VAR2*VAR3>," / @29
           "<VAR1 | VAR2> are acceptable expressions. See SAS manual" / @29
           "for a complete description under GLM procedure" ;
   put @20 "OPTION=  noint for a estimated model without the intercept";
   put @20 "INTERNATIONAL= 1 will produce an international avg. line. (0 by default)"/ @29
           "Only valid when BYVAR is equal to the country identifier" ;
   put @20 "REF=     indicates which levels of the CLVAR variables are to be"  / @29
           "treated as the reference levels. If REF is specified then  " /@29
           "CLVAR must also be specified" _page_ ;

   put @12 "Examples: Standard Linear Regression  "  /;
   put @14 "To run a standard regression of prose on d1 and age3 where prose" / @14
           "is based on 5 sets of plausible values(Prose1-prose5), d1 has 5 categories" / @14
           "and age3 has 3 categories, submit the following with a % sign " / @14
           "immediately preceeding the keyword stattool." // @14
           "%" "STATTOOL(wgt=popwt, rwgt=replic, nrep=30, npv=5, study=all, cntryno=cntrid," / @23
           "infile=in, method=regr, dvar=prose, dvarpv=1, ivar=d1 age3, " / @23
           "ivarpv=0 0, clvar=d1 age3,  out=c:\temp\test1 ) " // ;

   put @14 "To change the reference cells, say category 1 of D1 and category 2 of AGE3"  / @14
           "simply add the REF parameter" // @14
           "%" "STATTOOL(wgt=popwt, rwgt=replic, nrep=30, npv=5, study=all, cntryno=cntrid," / @23
           "infile=in, method=regr, dvar=prose, dvarpv=1, ivar=d1 age3, " / @23
           "ivarpv=0 0, clvar=d1 age3, ref=1 2, out=c:\temp\test2 ) " // ;

   put @14 "To treat both D1 and AGE3 as linear function of PROSE"  / @14
           "simply remove the CLVAR and REF parameters" // @14
           "%" "STATTOOL(wgt=popwt, rwgt=replic, nrep=30, npv=5, study=all, cntryno=cntrid," / @23
           "infile=in, method=regr, dvar=prose, dvarpv=1, ivar=d1 age3, " / @23
           "ivarpv=0 0, out=c:\temp\test3 ) " // ;

   put @14 "To run the same regression on PROSE1 rather than considering"  / @14
           "all plausible values, simply update parameters NPV, DVAR, DVARPV:" // @14
           "%" "STATTOOL(wgt=popwt, rwgt=replic, nrep=30, npv=1, study=all, cntryno=cntrid," / @23
           "infile=in, method=regr, dvar=prose1, dvarpv=0, ivar=d1 age3, " / @23
           "ivarpv=0 0, out=c:\temp\test4 ) " _page_ ;


   put @12 "Estimated means of y by x"  /;
   put @12 "METHOD=mean : " /;
   put @20 "Mandatory Parameters : " /;
   put @20 "DVAR=    put the name of the dependent y-variable or only the root" / @29
           "if based on plausible values " ;
   put @20 "DVARPV=  indicates whether the DVAR variable is based on " / @29
           "plausible values (DVARPV=1) or not (DVARPV=0) " ;
   put @20 "IVAR=    put the name of the independent x-variable(s) or only the root(s)" / @29
           "if based onplaus. values - IVAR variables must be qualitative " ;
   put @20 "IVARPV=  indicates whether the IVAR variable(s) is(are) based on " / @29
           "plausible values or not. -IVARPV=0 0 1- tells us that the first  " / @29
           "two IVAR variables are not based on plausible values but" / @29
           "the last one is" / ;
   put @20 "Optional Parameters : " /;
   put @20 "BYVAR=   put the name of the subpopulation variable(s) or only the root" / @29
           "if based on plausible values" ;
   put @20 "BYVARPV= indicates whether the BYVAR variable(s) is(are) based on " / @29
           "plausible values or not. -BYVARPV=0 0 1- tells us that the first  " / @29
           "two BYVAR variables are not based on plausible values but" / @29
           "the last one is"  ;
   put @20 "STAT =   Pxx where xx is an integer between 1 and 99. This will " / @29
           "give percentile estimates rather than mean estimates. Standard errors" / @29
           "are less stable under that method. Method = perc is strongly " / @29
           "recommended instead. However, this approach will allow for " / @29
           "cell to cell comparisons (see last page of this guide)";
   put @20 "PCT_CORRECT =  1 to get average percent correct estimates.  " / @29
           "Set to 0 by default. If set to 1 then either ITEMS = or" / @29
           "aright= , bright=, cright=, dright=, eright=, o1right, o2right=,"/ @29
           "must be specified. See below" ;
   put @20 "PCT_COND = put a SAS statement to define the target population.";
   put @20 "SCORED = 1 to tell the system that items are already scored." / @29
           "Set to 0 by default. If set to 1 then you must set " / @29
           "ITEMS = <list of items>. This  will " / @29
           "identify the set of items from which the average percent  " / @29
           "correct will be based on. You must also set PTS_2= list of " / @29
           "items worth a maximum of 2 points" / @29
           "If SCORED is set to 0 then you must set ARIGHT = <list of " / @29
           "items> to identify items for which <A> was the good answer, " / @29
           "BRIGHT = <list of items> to identifyes items for which <B> was" / @29  
           "the good answer, CRIGHT = <list of items> to identify items for" / @29  
           "which <C> was the good answer, DRIGHT = <list of items> to identify" / @29 
           "items for which <D> was the good answer, ERIGHT = <list of " / @29
           "items> to identify items for which <E> was the good answer, " / @29 
           "O1RIGHT = <list of open-ended items> to identify items worth 1 point," / @29  
           "and O2RIGHT = <list of open-ended items> to identify items worth" / @29 
           "2 points. The scoring of the items is adapted to the TIMSS" / @29
           "file structure only.";
   put @20 "INFILE =  put setup to save computing time after a first run " / @29
           "Since items are now scored from the previous run, average percent" / @29
           "correct estimates for subset of items may now be run. Do not " / @29
           "modify the BYVAR and IVAR variables. SCORED is set to 1 and " / @29
           "ITEMS is modify to represent the subset of items of interest"; 
   put @20 "INTERNATIONAL= 1 will produce an international avg. line. (0 by default)"/ @29
           "Only valid when BYVAR is equal to the country identifier" / ;


   put @12 "Examples: Estimated Means "  /;
   put @14 "To get estimated means of prose by d1 and age3 where prose" / @14
           "is based on 5 sets of plausible values(Prose1-prose5), d1 has 5 categories" / @14
           "and age3 has 3 categories, submit the following with a % sign " / @14
           "immediately preceeding the keyword stattool." // @14
           "%" "STATTOOL(wgt=popwt, rwgt=replic, nrep=30, npv=5, study=all, cntryno=cntrid," / @23
           "infile=in, method=mean, dvar=prose, dvarpv=1, ivar=d1 age3, ivarpv=0 0," / @23
           " out=c:\temp\test5 ) " //;
   put @14 "To get average percent correct in Mathematics where items are not " / @14
           "already scored, broken down by country " / @14
           "submit the following with a % sign " / @14
           "immediately preceeding the keyword stattool." // @14
           "%" "STATTOOL(wgt=totwgt, nrep=75, npv=1, study=timss, cntryno=idcntry," / @23
           "infile=in, method=mean, byvar=idcntry, byvarpv=0, PCT_correct=1, " / @23
           "ARIGHT = M022191  M022196  M022135  M022002  M022010  M022127, " / @23                                                                                                                               
           "BRIGHT = M022188  M022142  M022252  M022062  M022181  M012017, " / @23                                                                                                                                        
           "CRIGHT = M022251  M022189  M022139  M022154  M022004  M022005  M022021, " / @23                                                                                              
           "DRIGHT = M022194  M022198  M022144  M022016  M022043  M022049  M022066, " / @23                                                                                                             
           "ERIGHT = M022185  M022199  M022146  M022050  M012029  M012042, " / @23                                                                                                                    
           "O1RIGHT= M022202  M022148  M022253  M022156  M022008  M022012, " / @23                                                                                                   
           "O2RIGHT= M022261c M022232  M022234a M022234b," / @23
           "infile=in, method=mean, byvar=idcntry, byvarpv=0, PCT_correct=1, " / @23
           " pct_cond=if intrnd03, criter1=if totwgt>0, out=c:\temp\test5 ) " //;

   put @14 "To get average percent correct for a subset of these Mathematics items" / @14
           "already scored, broken down by country " / @14
           "submit the following with a % sign " / @14
           "immediately preceeding the keyword stattool." // @14
           "%" "STATTOOL(wgt=totwgt, nrep=75, npv=1, study=timss, cntryno=idcntry," / @23
           "infile=setup, method=mean, byvar=idcntry, byvarpv=0, PCT_correct=1, " / @23
           "ITEMS = M022191  M022196  M022252  M022062  M022234a M022234b, " / @23  
           "infile=in, method=mean, byvar=idcntry, byvarpv=0, scored=1, " / @23
           " pct_cond=if intrnd03, criter1=if totwgt>0, out=c:\temp\test5 ) " 
_page_ ;


   put @12 "Estimated mean differences of y by level of x"  /;
   put @12 "METHOD=diff : " /;
   put @20 "Mandatory Parameters : " /;
   put @20 "DVAR=    put the name of the dependent y-variable or only the root" / @29
           "if based on plausible values " ;
   put @20 "DVARPV=  indicates whether the DVAR variable is based on " / @29
           "plausible values (DVARPV=1) or not (DVARPV=0) " ;
   put @20 "IVAR=    put the name of the independent x-variable(s) or only the root(s)" / @29
           "if based on plaus. values- All IVAR variables must be qualitative " ;
   put @20 "IVARPV=  indicates whether the IVAR variable(s) is(are) based on " / @29
           "plausible values or not. -IVARPV=0 0 1- tells us that the first  " / @29
           "two IVAR variables are not based on plausible values but" / @29
           "the last one is" / ;
   put @20 "Optional Parameters : " /;
   put @20 "BYVAR=   put the name of the subpopulation variable(s) or only the root" / @29
           "if based on plausible values" ;
   put @20 "BYVARPV= indicates whether the BYVAR variable(s) is(are) based on " / @29
           "plausible values or not. -BYVARPV=0 0 1- tells us that the first  " / @29
           "two BYVAR variables are not based on plausible values but" / @29
           "the last one is" ;
   put @20 "REF=     indicates which levels of the IVAR variables are to be"  / @29
           "treated as the reference levels " / ;

   put @12 "Examples: Estimated Mean Differences "  /;
   put @14 "To get mean differences of prose by levels of d1 and age3 comparing all means to" / @14
           "the mean of the group defined by the last levels of the IVAR variables, where prose" / @14
           "is based on 5 sets of plausible values(Prose1-prose5), d1 has 5 categories" / @14
           "and age3 has 3 categories, submit the following with a % sign " / @14
           "immediately preceeding the keyword stattool." // @14
           "%" "STATTOOL(wgt=popwt, rwgt=replic, nrep=30, npv=5, study=all, cntryno=cntrid," / @23
           "infile=in, method=diff, dvar=prose, dvarpv=1, ivar=d1 age3, ivarpv=0 0," / @23
           " out=c:\temp\test6) " // ;

   put @14 "To change the reference cells, say category 1 of D1 and category 2 of AGE3"  / @14
           "simply add the REF parameter" // @14
           "%" "STATTOOL(wgt=popwt, rwgt=replic, nrep=30, npv=5, study=all, cntryno=cntrid," / @23
           "infile=in, method=diff, dvar=prose, dvarpv=1, ivar=d1 age3, " / @23
           "ivarpv=0 0, ref=1 2, out=c:\temp\test7) " _page_ ;

put @12 "Estimated Standard deviations of y by x"  /;
   put @12 "METHOD=stddev : " /;
   put @20 "Mandatory Parameters : " /;
   put @20 "DVAR=    put the name of the dependent y-variable or only the root" / @29
           "if based on plausible values " ;
   put @20 "DVARPV=  indicates whether the DVAR variable is based on " / @29
           "plausible values (DVARPV=1) or not (DVARPV=0) " ;
   put @20 "IVAR=    put the name of the independent x-variable(s) or only the root(s)" / @29
           "if based onplaus. values - IVAR variables must be qualitative " ;
   put @20 "IVARPV=  indicates whether the IVAR variable(s) is(are) based on " / @29
           "plausible values or not. -IVARPV=0 0 1- tells us that the first  " / @29
           "two IVAR variables are not based on plausible values but" / @29
           "the last one is" / ;
   put @20 "Optional Parameters : " /;
   put @20 "BYVAR=   put the name of the subpopulation variable(s) or only the root" / @29
           "if based on plausible values" ;
   put @20 "BYVARPV= indicates whether the BYVAR variable(s) is(are) based on " / @29
           "plausible values or not. -BYVARPV=0 0 1- tells us that the first  " / @29
           "two BYVAR variables are not based on plausible values but" / @29
           "the last one is"  ;
   put @20 "INTERNATIONAL= 1 will produce an international avg. line. (0 by default)"/ @29
           "Only valid when BYVAR is equal to the country identifier" / ;


   put @12 "Examples: Estimated Standard Deviations "  /;
   put @14 "To get estimated standard deviations of prose by d1 and age3 where prose" / @14
           "is based on 5 sets of plausible values(Prose1-prose5), d1 has 5 categories" / @14
           "and age3 has 3 categories, submit the following with a % sign " / @14
           "immediately preceeding the keyword stattool." // @14
           "%" "STATTOOL(wgt=popwt, rwgt=replic, nrep=30, npv=5, study=all, cntryno=cntrid," / @23
           "infile=in, method=stddev, dvar=prose, dvarpv=1, ivar=d1 age3, ivarpv=0 0," / @23
           " out=c:\temp\test5 ) " 
_page_ ;

   put @12 "Estimated population counts by x"  /;
   put @12 "METHOD=POPEST : " /;
   put @20 "Mandatory Parameters : " /;
   put @20 "IVAR=    put the name of the independent variable(s) or only the root(s)" / @29
           "if based on plausible values " ;
   put @20 "IVARPV=  indicates whether the IVAR variable(s) is(are) based on " / @29
           "plausible values or not. -IVARPV=0 0 1- tells us that the first  " / @29
           "two IVAR variables are not based on plausible values but" / @29
           "the last one is" / ;
   put @20 "Optional Parameters : " /;
   put @20 "BYVAR=   put the name of the subpopulation variable(s) or only the root" / @29
           "if based on plausible values" ;
   put @20 "BYVARPV= indicates whether the BYVAR variable(s) is(are) based on " / @29
           "plausible values or not. -BYVARPV=0 0 1- tells us that the first  " / @29
           "two BYVAR variables are not based on plausible values but" / @29
           "the last one is" / ;

   put @12 "Examples: Estimated Population Counts "  /;
   put @14 "To get estimated population counts by d1 and age3 where " / @14
           "d1 has 5 categories and age3 has 3 categories, submit the following with a % sign " / @14
           "immediately preceeding the keyword stattool." // @14
           "%" "STATTOOL(wgt=popwt, rwgt=replic, nrep=30, npv=5, study=all, cntryno=cntrid," / @23
           "infile=in, method=popest, ivar=d1 age3, ivarpv=0 0, out=c:\temp\test8 ) " _page_ ;

   put @12 "Crosstabs (Pop Counts & Percentages) "  /;
   put @12 "METHOD=crosstabs : " /;
   put @20 "Mandatory Parameters : " /;
   put @20 "IVAR=    put the name of the independent x-variable or only the root" / @29
           "if based on plaus. values. No more than 2 x-variables are allowed " ;
   put @20 "IVARPV=  indicates whether the IVAR variable is based on " / @29
           "plausible values (IVARPV=1) or not (IVARPV=0) " ;
   put @20 "Optional Parameters : " /;
   put @20 "BYVAR=   put the name of the subpopulation variable(s) or only the root" / @29
           "if based on plausible values" ;
   put @20 "BYVARPV= indicates whether the BYVAR variable(s) is(are) based on " / @29
           "plausible values or not. -BYVARPV=0 0 1- tells us that the first  " / @29
           "two BYVAR variables are not based on plausible values but" / @29
           "the last one is" / ;

   put @12 "Examples: Crosstabs "  /;
   put @14 "To get crosstabs Pop counts & percentages by d1 and age3 where " / @14
           "d1 has 5 categories and age3 has 3 categories, submit the following with a % sign " / @14
           "immediately preceeding the keyword stattool." // @14
           "%" "STATTOOL(wgt=popwt, rwgt=replic, nrep=30, npv=1, study=all, cntryno=cntrid," / @23
           "infile=in, method=crosstabs, ivar=d1 age3, ivarpv=0 0, " / @23
           "out=c:\temp\test9 ) " _page_ ;

put @12 "Correlation Coefficients "  /;
   put @12 "METHOD=corr : " /;
   put @20 "Mandatory Parameters : " /;
   put @20 "IVAR=    put the name of the independent x-variable or only the root" / @29
           "if based on plausible values. " ;
   put @20 "IVARPV=  indicates whether the IVAR variable is based on " / @29
           "plausible values (IVARPV=1) or not (IVARPV=0) " ;
   put @20 "Optional Parameters : " /;
   put @20 "BYVAR=   put the name of the subpopulation variable(s) or only the root" / @29
           "if based on plausible values" ;
   put @20 "BYVARPV= indicates whether the BYVAR variable(s) is(are) based on " / @29
           "plausible values or not. -BYVARPV=0 0 1- tells us that the first  " / @29
           "two BYVAR variables are not based on plausible values but" / @29
           "the last one is" / ;

   put @12 "Examples: Correlation Coefficients "  /;
   put @14 "To get correlation coefficientsbetween prose and doc " / @14
           "submit the following with a % sign " / @14
           "immediately preceeding the keyword stattool." // @14
           "%" "STATTOOL(wgt=popwt, rwgt=replic, nrep=30, npv=1, study=all, cntryno=cntrid," / @23
           "infile=in, method=corr, ivar=prose doc, ivarpv=1 1, " / @23
           "out=c:\temp\test9 ) " _page_ ;

put @12 "Tests on differences between Correlation Coefficients "  /;
   put @12 "METHOD=corrdiff : " /;
   put @20 "Mandatory Parameters : " /;
   put @20 "IVAR=    put the name of the independent x-variable or only the root" / @29
           "if based on plausible values. " ;
   put @20 "IVARPV=  indicates whether the IVAR variable is based on " / @29
           "plausible values (IVARPV=1) or not (IVARPV=0) " ;
   put @20 "Optional Parameters : " /;
   put @20 "BYVAR=   put the name of the subpopulation variable(s) or only the root" / @29
           "if based on plausible values" ;
   put @20 "BYVARPV= indicates whether the BYVAR variable(s) is(are) based on " / @29
           "plausible values or not. -BYVARPV=0 0 1- tells us that the first  " / @29
           "two BYVAR variables are not based on plausible values but" / @29
           "the last one is" / ;

   put @12 "Examples: Correlation Coefficients "  /;
   put @14 "To get correlation coefficientsbetween prose and doc " / @14
           "submit the following with a % sign " / @14
           "immediately preceeding the keyword stattool." // @14
           "%" "STATTOOL(wgt=popwt, rwgt=replic, nrep=30, npv=1, study=all, cntryno=cntrid," / @23
           "infile=in, method=corrdiff, ivar=prose doc, ivarpv=1 1, " / @23
           " out=c:\temp\test9 ) " _page_ ;



   put @12 "Estimated quantiles of y by x"  /;
   put @12 "METHOD=perc : " /;
   put @20 "Mandatory Parameters : " /;
   put @20 "STAT=    put n where 0<n<100. For medians, put STAT=50" ;
   put @20 "DVAR=    put the name of the dependent y-variable or only the root" / @29
           "if based on plausible values " ;
   put @20 "DVARPV=  indicates whether the DVAR variable is based on " / @29
           "plausible values (DVARPV=1) or not (DVARPV=0) " ;
   put @20 "IVAR=    put the name of the independent x-variable(s) or only the root(s)" / @29
           "if based on plausible values " ;
   put @20 "IVARPV=  indicates whether the IVAR variable(s) is(are) based on " / @29
           "plausible values or not. -IVARPV=0 0 1- tells us that the first  " / @29
           "two IVAR variables are not based on plausible values but" / @29
           "the last one is" / ;
   put @20 "Optional Parameters : " /;
   put @20 "CLEV=    put n where 0<n<1. CLEV is the one-side confidence limit level" / @29
           "CLEV=.975 gives you 95% lower and higher confidence limits (when" / @29
           "no plausible value variable) and " / @29
           "an estimated standard error based on Woodruff method." / @29
           "Any other value for CLEV will fail to produce confidence limits";
   put @20 "DDF=      the number of degrees of freedom. Usually set to NREP" / @29
           "but may need to be updated when dealing with subpopulations ";
   put @20 "BYVAR=   put the name of the subpopulation variable(s) or only the root" / @29
           "if based on plausible values" ;
   put @20 "BYVARPV= indicates whether the BYVAR variable(s) is(are) based on " / @29
           "plausible values or not. -BYVARPV=0 0 1- tells us that the first  " / @29
           "two BYVAR variables are not based on plausible values but" / @29
           "the last one is" / ;

   put @12 "Examples: quantiles of y by x "  /;
   put @14 "To get 27th percentile of prose by d1 and age3 where " / @14
           "d1 has 5 categories and age3 has 3 categories, submit the following with a % sign " / @14
           "immediately preceeding the keyword stattool." // @14
           "%" "STATTOOL(wgt=popwt, rwgt=replic, nrep=30, npv=1, study=all, cntryno=cntrid," / @23
           "infile=in, method=perc, stat=27, dvar=prose, dvarpv=1, ivar=d1 age3, " / @23
           "ivarpv=0 0, out=c:\temp\test10 ) " _page_ ;


   put @12 "Logistic regression of y over x"  /;
   put @12 "METHOD=logistic"  /;
   put @20 "Mandatory Parameters : " /;
   put @20 "WHERE=   indicated which two levels of the y-variable are to be " / @29
           "considered. WHERE=1 3 will consider only levels 1 and 3 ";
   put @20 "When more than two levels, this method will give a cumulative logit model" / @29
           "with p giving the probability of being in the lower categories" / @29
           "rather than in the higher categories";
   put @20 "DVAR=    put the name of the dependent y-variable or only the root" / @29
           "if based on plausible values from which proportions are derived" ;
   put @20 "DVARPV=  indicates whether the DVAR variable is based on " / @29
           "plausible values (DVARPV=1) or not (DVARPV=0) " ;
   put @20 "IVAR=    put the name of the independent x-variable(s) or only the root(s)" / @29
           "if based on plausible values. Can be left blank for a model with " / @29
           "intercept only. " ;
   put @20 "IVARPV=  indicates whether the IVAR variable(s) is(are) based on " / @29
           "plausible values or not. -IVARPV=0 0 1- tells us that the first  " / @29
           "two IVAR variables are not based on plausible values but" / @29
           "the last one is" / ;
   put @20 "Optional Parameters : " /;

   put @20 "BYVAR=   put the name of the subpopulation variable(s) or only the root" / @29
           "if based on plausible values" ;
   put @20 "BYVARPV= indicates whether the BYVAR variable(s) is(are) based on " / @29
           "plausible values or not. -BYVARPV=0 0 1- tells us that the first  " / @29
           "two BYVAR variables are not based on plausible values but" / @29
           "the last one is"  ;
   put @20 "CLVAR=   put the name of the qualitative independent x-variable(s) or only " / @29
           "the root if based on plausible values. CLVAR is a subset of IVAR" / @29
           "The highest levels of each CLVAR variable become the reference" ;
   put @20 "INTERACTION= specifies the interaction terms. <VAR1*VAR2>, <VAR1*VAR2*VAR3>," / @29
           "<VAR1 | VAR2> are acceptable expressions. See SAS manual" / @29
           "for a complete description under GLM procedure" ;
   put @20 "INTERNATIONAL= 1 will produce an international avg. line. (0 by default)"/ @29
           "Only valid when BYVAR is equal to the country identifier" ;
   put @20 "OPTION=  noint for a estimated model without the intercept";
   put @20 "REF=     indicates which levels of the CLVAR variables are to be"  / @29
           "treated as the reference levels. If REF is specified then  " /@29
           "CLVAR must also be specified" _page_ ;


   put @12 "Examples: Logistic Regression  "  /;
   put @14 "To run a logistic regression of prose on d1 and age3 where prose" / @14
           "is based on5 sets of plausible values(Prose1-prose5), d1 has 5 categories" / @14
           "and age3 has 3 categories, submit the following with a % sign " / @14
           "immediately preceeding the keyword stattool." // @14
           "%" "STATTOOL(wgt=popwt, rwgt=replic, nrep=30, npv=5, study=all, cntryno=cntrid," / @23
           "infile=in, method=logistic, dvar=prose, dvarpv=1, ivar=d1 age3, " / @23
           "ivarpv=0 0, clvar=d1 age3, clvarpv=0 0, out=c:\temp\test11) " // ;

   put @14 "To change the reference cells, say category 1 of D1 and category 2 of AGE3"  / @14
           "simply add the REF parameter" // @14
           "%" "STATTOOL(wgt=popwt, rwgt=replic, nrep=30, npv=5, study=all, cntryno=cntrid," / @23
           "infile=in, method=logistic, dvar=prose, dvarpv=1, ivar=d1 age3, " / @23
           "ivarpv=0 0, clvar=d1 age3, clvarpv=0 0, ref=1 2, out=c:\temp\test12 ) " // ;

   put @14 "To treat both D1 and AGE3 as linear function of PROSE"  / @14
           "simply remove the CLVAR, CLVARPV and REF parameter" // @14
           "%" "STATTOOL(wgt=popwt, rwgt=replic, nrep=30, npv=5, study=all, cntryno=cntrid," / @23
           "infile=in, method=logistic, dvar=prose, dvarpv=1, ivar=d1 age3, " / @23
           "ivarpv=0 0, out=c:\temp\test13) " // ;

   put @14 "To run the same regression on PROSE1 rather than considering"  / @14
           "all plausible values, simply update parameters NPV, DVAR, DVARPV:" // @14
           "%" "STATTOOL(wgt=popwt, rwgt=replic, nrep=30, npv=1, study=all, cntryno=cntrid," / @23
           "infile=in, method=logistic, dvar=prose1, dvarpv=0, ivar=d1 age3, " / @23
           "ivarpv=0 0, out=c:\temp\test14) " _page_ ;

   put @12 "Multinomial logistic regression of y over x"  /;
   put @12 "METHOD=Multinomial"  /;
   put @20 "Mandatory Parameters : " /;
   put @20 "WHERE=   indicated which levels of the y-variable are to be " / @29
           "considered. WHERE=1 2 3 will consider levels 1, 2 and 3 ";
   put @20 "When only two levels, this method will give a logistic regression." ;

   put @20 "DVAR=    put the name of the dependent y-variable or only the root" / @29
           "if based on plausible values from which proportions are derived" ;
   put @20 "DVARPV=  indicates whether the DVAR variable is based on " / @29
           "plausible values (DVARPV=1) or not (DVARPV=0) " ;
   put @20 "IVAR=    put the name of the independent x-variable(s) or only the root(s)" / @29
           "if based on plausible values. Results are misleading if left blank. " ;
   put @20 "IVARPV=  indicates whether the IVAR variable(s) is(are) based on " / @29
           "plausible values or not. -IVARPV=0 0 1- tells us that the first  " / @29
           "two IVAR variables are not based on plausible values but" / @29
           "the last one is" / ;
   put @20 "Optional Parameters : " /;

   put @20 "EVENT =  put the value of the reference for the response variable" / @29
           "DBVAR.";
   put @20 "CLVAR=   put the name of the qualitative independent x-variable(s) or only " / @29
           "the root if based on plausible values. CLVAR is a subset of IVAR" / @29
           "The highest levels of each CLVAR variable become the reference" ;
   put @20 "BYVAR=   put the name of the subpopulation variable(s) or only the root" / @29
           "if based on plausible values" ;
   put @20 "BYVARPV= indicates whether the BYVAR variable(s) is(are) based on " / @29
           "plausible values or not. -BYVARPV=0 0 1- tells us that the first  " / @29
           "two BYVAR variables are not based on plausible values but" / @29
           "the last one is" ;
   put @20 "INTERNATIONAL= 1 will produce an international avg. line. (0 by default)"/ @29
           "Only valid when BYVAR is equal to the country identifier" ;
   put @20 "REF=     indicates which levels of the CLVAR variables are to be"  / @29
           "treated as the reference levels. If REF is specified then  " /@29
           "CLVAR must also be specified" ;
   put @20 "OPTION=  noint for a estimated model without the intercept" _page_ ;

   
   put @12 "Cell to cell comparisons"  /;
   put @12 "METHOD= (all methods already discussed but <diff>, <perc>, <corr>) "  /;
   put @12 "To avoid any problem with this procedure, please just add the "  /;
   put @12 "following sets of 3 parameters to whatever you had already submitted."  /;
   put @12 "Note that if a BYVAR was specified, then all comparisons will be "  /;
   put @12 "done within the BYVAR levels by opposition to across levels."  /;
   put @20 "Mandatory Parameters : " /;

   put @20 "COMPARE1=Specify the correct values of IVAR to uniquely identify the cell" / @29
            "of reference in the first cell to cell comparison. No equal sign " / @29
            "allowed unless in between parenthesis (see examples below). The " / @29
            "specification of this parameter is based on the IVAR variables  " / @29
            "only or is based on the value of the variable PARAMETER found" / @29
            "in the SAS output window where blanks are to be ignored" / @29
            "see examples below."   ;
   put @20 "TO1=     Specify the correct values of IVAR to uniquely identify the cell" / @29
            "to be compared to in the first cell to cell comparison. No equal sign " / @29
            "allowed unless in between parenthesis (see examples below). The " / @29
            "specification of this parameter is based on the IVAR variables  " / @29
            "only or is based on the value of the variable PARAMETER found" / @29
            "in the SAS output window where blanks are to be ignored" / @29
            "see examples below."   ;
   put @20 "Label1=  gives a description of the comparison of the two cells specified" / @29
           " in COMPARE1 and TO1 for the first cell to cell comparison.  "  ;
   put @20 "COMPARE2=Specify the correct values of IVAR to uniquely identify the cell" / @29
            "of reference in the second cell to cell comparison. No equal sign " / @29
            "allowed unless in between parenthesis (see examples below). The " / @29
            "specification of this parameter is based on the IVAR variables  " / @29
            "only or is based on the value of the variable PARAMETER found" / @29
            "in the SAS output window where blanks are to be ignored" / @29
            "see examples below."   ;
   put @20 "TO2=     Specify the correct values of IVAR to uniquely identify the cell" / @29
            "to be compared to in the second cell to cell comparison. No equal sign " / @29
            "allowed unless in between parenthesis (see examples below). The " / @29
            "specification of this parameter is based on the IVAR variables  " / @29
            "only or is based on the value of the variable PARAMETER found" / @29
            "in the SAS output window where blanks are to be ignored" / @29
            "see examples below."   ;
   put @20 "Label2=  gives a description of the comparison of the two cells specified" / @29
           "in COMPARE2 and TO2 for the second cell to cell comparison" // @29
           "You may specified up to 9 cell to cell comparisons (using compare3, to3 " / @29
           "label3 up to compare9, to9 and label9 the way described above" 
  
     _page_ ;

   put @12 "Examples: Cell to cell comparisons  "  /;
   put @14 "To run a comparison on mean prose between people with high DOC results and " / @14
           "SES of 2 and people with low DOC at the same level of SES where DOC is a PV" / @14
           "and SES is not, submit the following with a % sign " / @14
           "immediately preceeding the keyword stattool." // @14
           "%" "STATTOOL(wgt=popwt, rwgt=replic, nrep=30, npv=5, study=all, cntryno=cntrid," / @23
           "infile=in, method=mean, dvar=prose, dvarpv=1, ivar=DOCGR SES, " / @23
           "ivarpv=1 0, out=c:\temp\test11) " // @14
           " And then submit the following" // @14
           "%" "STATTOOL(wgt=popwt, rwgt=replic, nrep=30, npv=5, study=all, cntryno=cntrid," / @23
           "infile=in, method=mean, dvar=prose, dvarpv=1, ivar=DOCGR SES, " / @23
           "ivarpv=1 0, compare1=(DOCGR=2 & SES=2),To1=(DOCGR=1 & SES=2)," / @23
           "label1=Difference between High and low DOC for SES=2, out=c:\temp\test11) " // ;

   put @14 "To run a comparison on regression coefficients for SES=3 and " / @14
           "for SES=2 in a standard linear regression (or any type of regression)" / @14
           "submit the following with a % sign " / @14
           "immediately preceeding the keyword stattool." // @14
           "%" "STATTOOL(wgt=popwt, rwgt=replic, nrep=30, npv=5, study=all, cntryno=cntrid," / @23
           "infile=in, method=regression, dvar=prose, dvarpv=1, ivar=SES, " / @23
           "ivarpv=0, out=c:\temp\test11) " // @14
           " And then submit the following (note that no blank is left between SES and 3)" // @14
           "%" "STATTOOL(wgt=popwt, rwgt=replic, nrep=30, npv=5, study=all, cntryno=cntrid," / @23
           "infile=in, method=regresion, dvar=prose, dvarpv=1, ivar=SES, " / @23
           "ivarpv=0, compare1=(parameter=""SES3""),To1=(parameter=""SES2"")," / @23
           "label1=Difference between coefficients from SES=3 to SES=2, " / @23
           "out=c:\temp\test11) " _page_ ;




   put @2 "Optional Parameters: " /;
   put @2 "FAY=      put FAY factor when BRR is required " ;
   put @2 "JKZ=      identifies the jackknife zones. For TIMSS and PIRLS only " ;
   put @2 "JKI=      identifies the jackknife replicates. For TIMSS and PIRLS only " ;
   put @2 "DDF=       the number of degrees of freedom. Usually set to NREP" / @12
           "but may need to be updated when dealing with subpopulations ";
   put @2 "CRITER1=  Any SAS statement(can be used to program an IF statement) " ;
   put @2 "CRITER2=  Any SAS statement(can be used to program an IF statement) " ;
   put @2 "CRITER3=  Any SAS statement(can be used to program an IF statement) " ;
   put @2 "OUT=      Any name to be given to the html output file. " / @12 
          "Complete path has to be specified without quotes. " / @12
          "For example out=c:\temp\output1 will put the results in the file" / @12
          "c:\temp\output1.html By default, the results go into C:\temp\out.html"/ @12
          "When using method = corrdiff the keyword diff is automatically added" / @12
          "to the file name" //;

put @12 "Examples: Cell to cell comparisons  "  /;
   put @14 
           "%" "STATTOOL(wgt=popwt, rwgt=replic, nrep=30, npv=5, study=all, cntryno=cntrid,"
            / @23
           "infile=in, method=mean, dvar=prose, dvarpv=1, ivar=DOCGR SES, " / @23
           "ivarpv=1 0, criter1=if popwt > 0 , out=c:\temp\test11) " ;
           




              end;
run;

ods html close;
